ozi-new webui

### {_('adm-disclaimer-title')}

×

{disclaimer_text}

### {_('btn-options')}

×

{_('term-user-interface')} {_('opt-menu-language-text')}
{_('term-output')} {_('opt-menu-copyright-head-input')}

#####

{config['new']['copyright_head'] if config['new']['copyright_head'] else COPYRIGHT_HEAD}
{_('opt-menu-enable-cython').replace('$value', '')}
{_('opt-menu-enable-uv').replace('$value', '')}
{_('opt-menu-github-harden-runner').replace('$value', '')}
{_('opt-menu-update-wrapfile').replace('$value', '')}
{_('term-input')} {_('opt-menu-allow-file-input')}

#####

{', '.join(METADATA.spec.python.src.allow_files)}
{_('opt-menu-strict').replace('$value', '')}
{_('opt-menu-verify-email').replace('$value', '')}

# {_('web-core-metadata')}

{_('pro-name')}

#####

{_('pro-summary')}

#####

{_('pro-keywords')}

#####

{_('pro-author')}

#####

{_('pro-author-email')}

#####

{_('pro-maintainer')}

#####

{_('pro-maintainer-email')}

#####

{_('pro-project-urls-cbl')}

#####

{_('pro-requires-dist')}

#####

{_('pro-readme-type')}

#####

{_('pro-license-expression')}
{_('edit-menu-btn-license-exception')}
{_('pro-license')}
{_('edit-menu-btn-license-file')}
{_('pro-classifier-cbl', key=_('edit-menu-btn-status'))}
{_('pro-classifier-cbl', key=_('edit-menu-btn-language'))}
{_('pro-classifier-cbl', key=_('edit-menu-btn-audience'))}
{_('pro-classifier-cbl', key=_('edit-menu-btn-environment'))}
{_('pro-classifier-cbl', key=_('edit-menu-btn-framework'))}
{_('pro-classifier-cbl', key=_('edit-menu-btn-topic'))}
{_('adm-confirm')}